#! /bin/bash
# -----------------------------------------------------------------------------
# f2cad: Convert Fortran to C++ AD Types: Copyright (C) 2005-10 Bradley M. Bell
# Authors:  Bradley M. Bell    bradbell at washington dot edu
# License:  GNU Public License Version 2 or higher
# -----------------------------------------------------------------------------
#
if [ "$1" == "" ]
then
	echo "usage: build_sources.sh f2c_dir"
	echo "where f2c_dir/bin/f2c is the f2c command."
	exit 1
fi
set -eu
f2c_dir="$1"
#
# clean out old build sources
list="
	f2c.p
	cpp
	f.omh
	p.omh
	f2cad
"
for dir in $list
do
	if [ -e $dir ]
	then
		echo "rm -rf $dir"
		rm -rf $dir
	fi
done
#
# list of routines is determined by fortran directory contents
fortran_list=`ls fortran | sed -e 's|\.f$||'`
# -------------------------------------------------------------------------
# build the f2c.p directory 
#
mkdir f2c.p
cd f2c.p
for name in $fortran_list
do
	echo "f2c ../fortran/$name.f -P -U -r8 -!c"
	$f2c_dir/bin/f2c ../fortran/$name.f -P -U -r8 -!c
	#
	echo "mv $name.P $name.p"
	mv $name.P $name.p
done
cd ..
# -------------------------------------------------------------------------
# build the cpp directory 
#
mkdir cpp
if ! cd cpp
then
	echo "Cannot create the cpp directory"
	exit 1
fi
for name in $fortran_list
do
	# create $name.c from $name.f
	echo "f2c ../fortran/$name.f -U -r8"
	$f2c_dir/bin/f2c ../fortran/$name.f -U -r8
	# create $name.cpp from $name.c
	echo "sed -f ../sed/c2cpp.sed < $name.c > $name.cpp"
	sed -f ../sed/c2cpp.sed < $name.c > $name.cpp
	# remove the temporary 
	rm $name.c 
done
cd ..
# -------------------------------------------------------------------------
# build the f.omh directory 
#
mkdir f.omh
if ! cd f.omh
then
	echo "Cannot create the f.omh directory"
	exit 1
fi
for name in $fortran_list
do
cat << EOF > $name.f.omh
\$begin $name.f\$\$
\$spell
	$name
\$\$

\$section $name.f\$\$

\$code
\$verbatim%fortran/$name.f%\$\$
\$\$

\$end
EOF
done
cd ..
# -------------------------------------------------------------------------
# build the p.omh directory 
#
mkdir p.omh
if ! cd p.omh
then
	echo "Cannot create the p.omh directory"
	exit 1
fi
for name in $fortran_list
do
	# create $name.p.omh from $name.p
	echo "sed -f ../sed/p2omh.sed < ../f2c.p/$name.p > $name.p.omh"
	sed -f ../sed/p2omh.sed < ../f2c.p/$name.p > $name.p.omh
done
cd ..
# -------------------------------------------------------------------------
# build the f2cad directory 
#
mkdir f2cad
if ! cd f2cad
then
	echo "Cannot create the f2cad directory"
	exit 1
fi
for name in $fortran_list
do
	NAME=`echo $name | tr 'a-z' 'A-Z'`
cat << EOF > p2hpp.$$
1,1s|^|# ifndef ${NAME}_INCLUDED\\n# define ${NAME}_INCLUDED\\n\\n# include <f2cad/f2cad.hpp>\\n\\n|
#
s/extern int ${name}_(.*/namespace f2cad {\\n&\\n}\\n\\n# endif/
s/extern integer ${name}_(.*/namespace f2cad {\\n&\\n}\\n\\n# endif/
s/extern doublereal ${name}_(.*/namespace f2cad {\\n&\\n}\\n\\n# endif/
#
# xerror prototype is a special case
s/extern int xerror_(char [*]messg,/extern int xerror_(const char *messg,/
#
/^\/\*:ref:/d
EOF
	# create $name.p.omh from $name.p
	echo "sed -f p2omh.$$ < ../f2c.p/$name.p > $name.p.omh"
	sed -f p2hpp.$$ < ../f2c.p/$name.p > $name.hpp
	# remove temporary file
	rm p2hpp.$$
done
echo "sed -f ../sed/f2ch2hpp.sed < $f2c_dir/include/f2c.h > f2cad.hpp"
sed -f ../sed/f2ch2hpp.sed < $f2c_dir/include/f2c.h > f2cad.hpp
cd ..
